from meta import util
from combat import combat_system
from combat import monster_classes

"""
Options - Unvisited: 
    1. Talk To Fisherman
    2. Stand on the edge of the docks and peer over the ocean.
    3. Investigate Fishing Warehouse
    4. Leave

Options - Visited: 
    1. Peer Over the Docks once again
    2. Enter the Warehouse
    3. Talk to ghost
    3. Leave

Areas Adjacent:
    PC House
    Town Center

Monsters:
    Rat

People:
    Fisherman
    Ghost

Requirements:
    Talked to Victor

Exit condition:
        self.flag_beat_rat = True
        self.flag_retreive_fish = True

"""


# Naming convention is ScenarioYourArea
class ScenarioDocks(object):
    def __init__(self, nav, player):
        self.PC = player
        self.nav = nav
        self.name = "The Docks"
        self.initial_description = """
You enter a clearing on the edge of town with an old, well maintained warehouse overlooking the ocean.     
On the wharf, you spot a crusty looking fisherman and the aforementioned warehouse.l
        """
        self.flag_retreive_fish = False
        self.flag_beat_rat = False
        self.flag_visited = False
        self.exiting = False
        self.exit_condition = False

    def retreive_fish(self):
        print("The fishman regards you with")
        self.flag_retreive_fish = True
        self.PC.inventory.append("fish")

    def investigate_warehouse(self):
        if self.flag_retreive_fish:
            print("""You use the key given to you to now open the large iron door...""")
            rat = monster_classes.Rat
            combat_system.quick_combat(rat, self.PC)
            self.flag_beat_rat = True
        else:
            print("The door is locked... There must be a key around here somewhere.")

    def leave(self):
        print("You turn and exit the building, startled by your engagement with the rat but happy that it's over.")
        self.exiting = True

    def start(self):
        if self.flag_visited:
            self.visited()
        else:
            self.unvisited()

    def unvisited(self):
        # Option list to print out
        options = ["Talk to Fisherman", "Investigate warehouse"]
        # Function list to execute when menu option is selected
        exec = [self.retreive_fish, self.investigate_warehouse]
        ev = util.EventHandler()
        print(self.initial_description)
        ev.wait_for_user()
        util.clear()
        while not self.exiting:
            # Do this if both flags are True
            if self.flag_retreive_fish and self.flag_beat_rat:
                if not self.exit_condition:
                    options.append("Leave")
                    exec.append(self.leave)
                self.exit_condition = True
            util.menu_generator(options, exec)
        self.nav.travel()

    def visited(self):
        pass